.. _notebook-tutorial:

Notebook Tutorial
-----------------

The IPython notebook is a powerful system for literate codoing - a style of
writing code that embeds input, output, and explanatory text into one document.

yt has deep integration with the IPython notebook, explained in-depth in the
other example notebooks and the rest of the yt documentation.  This page is here
to give a brief introduction to the notebook its self.

To start the notebook, enter the following command at the bash command line:

.. code-block:: bash

   $ ipython notebook

Depending on your default web browser and system setup this will open a web
browser and direct you to the notebook dahboard.  If it does not,  you might
need to connect to the notebook manually.  See the `IPython documentation
<http://ipython.org/ipython-doc/stable/notebook/notebook.html#starting-the-notebook-server>`_
for more details.

For the notebook tutorial, we rely on example notebooks that are part of the
IPython documentation.  We link to static nbviewer versions of the 'evaluated'
versions of these example notebooks.  If you would like to run them locally on
your own computer, simply download the notebook by clicking the 'Download
Notebook' link in the top right corner of each page.

1. `IPython Notebook Tutorials <http://nbviewer.ipython.org/github/ipython/ipython/blob/master/examples/Notebook/Index.ipynb>`_
